@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Dist::Zilla::PluginBundle::DAGOLDEN;
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 # Dependencies
 use autodie 2.00;
@@ -9,7 +9,7 @@ use Moose 0.99;
 use Moose::Autobox;
 use namespace::autoclean 0.09;
 
-use Dist::Zilla 4.102341; # authordeps
+use Dist::Zilla 4.3; # authordeps
 
 use Dist::Zilla::PluginBundle::Filter ();
 use Dist::Zilla::PluginBundle::Git ();
@@ -19,6 +19,7 @@ use Dist::Zilla::Plugin::CheckChangesHasContent ();
 use Dist::Zilla::Plugin::CheckExtraTests ();
 use Dist::Zilla::Plugin::CheckPrereqsIndexed 0.002 ();
 use Dist::Zilla::Plugin::CompileTests ();
+use Dist::Zilla::Plugin::CopyFilesFromBuild ();
 use Dist::Zilla::Plugin::Git::NextVersion ();
 use Dist::Zilla::Plugin::GithubMeta 0.10 ();
 use Dist::Zilla::Plugin::InsertCopyright 0.001 ();
@@ -29,6 +30,7 @@ use Dist::Zilla::Plugin::OurPkgVersion 0.001008 ();
 use Dist::Zilla::Plugin::PodSpellingTests ();
 use Dist::Zilla::Plugin::PodWeaver ();
 use Dist::Zilla::Plugin::PortabilityTests ();
+use Dist::Zilla::Plugin::ReadmeAnyFromPod ();
 use Dist::Zilla::Plugin::ReadmeFromPod ();
 use Dist::Zilla::Plugin::TaskWeaver 0.101620 ();
 use Dist::Zilla::Plugin::Test::Version ();
@@ -105,7 +107,7 @@ sub configure {
     [ 'Git::NextVersion' => { version_regexp => $self->version_regexp } ],
 
   # gather and prune
-    'GatherDir',          # core
+    [ GatherDir => { exclude_filename => [qw/README.pod META.json/] }], # core
     'PruneCruft',         # core
     'ManifestSkip',       # core
 
@@ -120,6 +122,12 @@ sub configure {
   # generated distribution files
     'ReadmeFromPod',
     'License',            # core
+    [ ReadmeAnyFromPod => { # generate in root for github, etc.
+        type => 'pod',
+        filename => 'README.pod',
+        location => 'root',
+      }
+    ],
 
   # generated t/ tests
     [ CompileTests => { fake_home => 1 } ],
@@ -151,11 +159,21 @@ sub configure {
     'ShareDir',           # core
     'MakeMaker',          # core
 
+  # copy files from build back to root for inclusion in VCS
+  [ CopyFilesFromBuild => {
+      copy => 'META.json',
+    }
+  ],
+
   # manifest -- must come after all generated files
     'Manifest',           # core
 
   # before release
-    'Git::Check',
+    [ 'Git::Check' =>
+      {
+        allow_dirty => [qw/dist.ini Changes README.pod META.json/]
+      }
+    ],
     'CheckPrereqsIndexed',
     'CheckChangesHasContent',
     'CheckExtraTests',
@@ -169,7 +187,12 @@ sub configure {
   # Note -- NextRelease is here to get the ordering right with
   # git actions.  It is *also* a file munger that acts earlier
 
-    [ 'Git::Commit' => 'Commit_Dirty_Files' ], # Changes and/or dist.ini
+    # commit dirty Changes, dist.ini, README.pod, META.json
+    [ 'Git::Commit' => 'Commit_Dirty_Files' =>
+      {
+        allow_dirty => [qw/dist.ini Changes README.pod META.json/]
+      }
+    ],
     [ 'Git::Tag' => { tag_format => $self->tag_format } ],
 
     # bumps Changes
@@ -208,7 +231,7 @@ Dist::Zilla::PluginBundle::DAGOLDEN - Dist::Zilla configuration the way DAGOLDEN
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 SYNOPSIS
 
@@ -226,6 +249,9 @@ following dist.ini:
  
    ; choose files to include
    [GatherDir]         ; everything under top dir
+   exclude_filename = README.pod   ; skip this generated file
+   exclude_filename = META.json    ; skip this generated file
+ 
    [PruneCruft]        ; default stuff to skip
    [ManifestSkip]      ; if -f MANIFEST.SKIP, skip those, too
  
@@ -238,6 +264,10 @@ following dist.ini:
    ; generated files
    [License]           ; boilerplate license
    [ReadmeFromPod]     ; from Pod (runs after PodWeaver)
+   [ReadmeAnyFromPod]  ; create README.pod in repo directory
+   type = pod
+   filename = README.pod
+   location = root
  
    ; t tests
    [CompileTests]      ; make sure .pm files all compile
@@ -278,6 +308,10 @@ following dist.ini:
    ; manifest (after all generated files)
    [Manifest]          ; create MANIFEST
  
+   ; copy META.json back to repo dis
+   [CopyFilesFromBuild]
+   copy = META.json
+ 
    ; before release
    [Git::Check]        ; ensure all files checked in
    [CheckPrereqsIndexed]    ; ensure prereqs are on CPAN
@@ -385,9 +419,9 @@ progress on the request by the system.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<http://github.com/dagolden/dist-zilla-pluginbundle-dagolden>
+L<https://github.com/dagolden/dist-zilla-pluginbundle-dagolden>
 
-  git clone http://github.com/dagolden/dist-zilla-pluginbundle-dagolden
+  git clone https://github.com/dagolden/dist-zilla-pluginbundle-dagolden.git
 
 =head1 AUTHOR
 
